package projekt.enigma.model;

import javafx.scene.control.Alert;
import javafx.scene.control.Alert.AlertType;
import projekt.enigma.App;

/**
 * In dieser Klasse werden Fehler behandelt und an den User/Admin/Entwickler ausgegeben
 */
public class Fehler {

    private static final String FUNCTION_PREFIX = "- ";
    private static final String MESSAGE_PREFIX = "--> ";

    /**
     * Zeige Fehler Dialog
     *
     * @param type    : String : Art der Meldung (warning/information/error)
     * @param subject : String : Titel des Dialoges
     * @param message : String : Nachricht der Meldung
     */
    public void showErrorDialog(String type, String subject, String message) {
        Alert alert;

        new Fehler().debug(this.getClass().getName() + "."
                + new Throwable().getStackTrace()[0].getMethodName(), true);

        /* Der Titel darf auch als leerer String uebergeben werden, dann wird ein Default gesetzt */
        if (subject.equals("")) {
            subject = "Es ist ein Fehler aufgetreten";
        }

        /* Welcher Fehler Typ wurde uebergeben? */
        switch (type) {
            case "warning":
                alert = new Alert(AlertType.WARNING);
                break;

            case "info":
                alert = new Alert(AlertType.INFORMATION);
                break;

            case "error":
                alert = new Alert(AlertType.ERROR);
                break;

            default:
                alert = new Alert(AlertType.NONE);
        }

        //Anzeige des Alerts definieren
        alert.setTitle(subject);
        alert.setHeaderText(null);
        alert.setContentText(message);
        alert.showAndWait();
    }

    /**
     * Unter zuhilfenahme dieser Funktion koennen Debug Meldungen auf der Konsole ausgegeben werden,
     * wenn in der App.java der Getter getDebug einen int > 0 zurueck gibt.
     * Ueber diesen Getter kann man steuern ob Meldungen in der Konsole angezeigt werden sollen oder nicht.
     *
     * @param message    : String : Nachricht
     * @param isFunction : boolean : Gibt an ob ein Funktionsname übergeben wird oder eine Debug Meldung
     */
    public void debug(String message, boolean isFunction) {
        if (App.getDebug() != 0) {
            if (isFunction) {
                System.out.println(FUNCTION_PREFIX + message);
            } else {
                System.out.println(MESSAGE_PREFIX + message);
            }
        }
    }

    /**
     * Umter zuhilfenahme dieser Funktion koennen Debug Meldungen auf der Konsole ausgegeben werden,
     * wenn in der App.java der Getter getDebug einen int > 0 zurueck gibt.
     * Ueber diesen Getter kann man steuern ob Meldungen in der Konsole angezeigt werden sollen oder nicht.
     *
     * @param message    : String : Nachricht
     * @param isFunction : boolean : Gibt an ob ein Funktionsname übergeben wird oder eine Debug Meldung
     */
    public void debug(String message, boolean isFunction, int debugLevel) {

        if (App.getDebug() != 0 && (App.getDebug() >= debugLevel || App.getDebug() == 3)) {
            if (isFunction) {
                System.out.println(FUNCTION_PREFIX + message);
            } else {
                System.out.println(MESSAGE_PREFIX + message);
            }
        }
    }
}